# SKInkAnimator

[![CI Status](http://img.shields.io/travis/rafael.vrmoura@gmail.com/SKInkAnimator.svg?style=flat)](https://travis-ci.org/rafael.vrmoura@gmail.com/SKInkAnimator)
[![Version](https://img.shields.io/cocoapods/v/SKInkAnimator.svg?style=flat)](http://cocoapods.org/pods/SKInkAnimator)
[![License](https://img.shields.io/cocoapods/l/SKInkAnimator.svg?style=flat)](http://cocoapods.org/pods/SKInkAnimator)
[![Platform](https://img.shields.io/cocoapods/p/SKInkAnimator.svg?style=flat)](http://cocoapods.org/pods/SKInkAnimator)

SKInkAnimator is the framework to work with game assests generated by InkAnimator app in `SpriteKit` based games.
Always that you export your assets on `InkAnimator`, the iPad app exports a `<EntityName>.xml` file that have all the information about the game element's structure, skins and animations. And your assets organized in folders that represents the entity's bones. Use `SKInkAnimator` framework to instantiate entity's objects, load and set skins and load and run animations.

## Example

To run the example project, clone the repo, and run `pod install` from the Example directory first.

## Installation

SKInkAnimator is available through [CocoaPods](http://cocoapods.org). To install
it, simply add the following line to your Podfile:

## How to use

- Drag and drop the `<EntityName>.xml` file into your SpriteKit project on `Xcode`.
- Drag and drop the asset folders into the `Assets.xcassets` folder.
- Use the SKInkAnimator API to instantiate entity objects, set skins and run animations

#### Instantiating an entity object:
```swift
import SKInkAnimator
...
let entity = IAEntity(withName: "EntityName")
self.scene.addChild(entity)
```

#### Setting entity's skins:
```swift
entity.setSkin(named: "Dark_Knight")
```
#### Running animations:
```swift
// run the animation once
entity.run(animationNamed: "Running")

// Run the animation 3 times
entity.run(animationNamed: "Idle" , times: 3)

// Run the animation forever
entity.runForever(animationNamed: "Running")
```

#### Preloading Skins:

```swift
// Preloading the textures for skin named "Knight"
entity.preload(skinNamed: "Knight") {
// Callback
}

// Preloading textures for a set of skins
entity.preload(skins: ["Dark_Knight", "Light_Knight", "Golden_Knight"]) {
// Callback
}

// Releasing unused textures from memory
entity.releaseSkin(named: "Dark_Knight")
```

#### Preloading Animations:

```swift
// Preloading the animation named "Running"
entity.preload(animationNamed: "Running") {
// Callback    
}

// Preloading a set of animations
entity.preload(animations: ["Running", "Idle"]) {
// Callback
}

// Releasing unused animations from memory
entity.releaseAnimation(named: "Running")
```

```ruby
pod "SKInkAnimator"
```

## Author

rafael.vrmoura@gmail.com

## License

SKInkAnimator is available under the MIT license. See the LICENSE file for more info.
